@@ -35,4 +35,4 @@ def send_msg(tk,lg):
     
     server.quit()
     
-    print("successfully sent email to %s:" % (msg['To']))
\ No newline at end of file
+    print('this is true ')
\ No newline at end of file
